"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const iam_1 = require("./iam");
const file_1 = require("../utils/file");
const varset_1 = require("../utils/varset");
async function createRole(role) {
    const params = Object.assign({}, role);
    params.AssumeRolePolicyDocument = JSON.stringify(params.AssumeRolePolicyDocument, null, 4);
    const data = await iam_1.iam.createRole(params).promise();
    return data.Role;
}
exports.createRole = createRole;
async function getAttachedPoliciesByRole(roleName) {
    const params = { RoleName: roleName };
    const data = await iam_1.iam.listAttachedRolePolicies(params).promise();
    return data.AttachedPolicies;
}
exports.getAttachedPoliciesByRole = getAttachedPoliciesByRole;
async function getRole(roleName) {
    try {
        const params = { RoleName: roleName };
        const data = await iam_1.iam.getRole(params).promise();
        const role = data.Role;
        role.AssumeRolePolicyDocument = JSON.parse(decodeURIComponent(role.AssumeRolePolicyDocument));
        return role;
    }
    catch (err) {
        if (err.code === 'NoSuchEntity')
            return null;
        throw err;
    }
}
exports.getRole = getRole;
async function getInstanceProfile(roleName) {
    try {
        const params = { InstanceProfileName: roleName };
        const data = await iam_1.iam.getInstanceProfile(params).promise();
        return data.InstanceProfile;
    }
    catch (err) {
        if (err.code === 'NoSuchEntity')
            return null;
        throw err;
    }
}
exports.getInstanceProfile = getInstanceProfile;
function isEc2Role(role) {
    return role.AssumeRolePolicyDocument.Statement[0].Principal.Service === "ec2.amazonaws.com";
}
exports.isEc2Role = isEc2Role;
async function readRoleFile(filePath, varSet) {
    let name = '';
    try {
        name = path_1.default.basename(filePath, '.json');
        const text = await file_1.readFile(filePath);
        return {
            name,
            document: varset_1.parseJSON(text, varSet),
        };
    }
    catch (err) {
        console.error(`Failed to read ${name}`);
        throw err;
    }
}
exports.readRoleFile = readRoleFile;
