"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * delete matched IAM polices
 */
const StreamUtils = require('@tilfin/stream-utils');
const promisedLife = require('promised-lifestream');
const prompt_1 = __importDefault(require("./utils/prompt"));
const iam_1 = require("./aws/iam");
const list_stream_1 = require("./aws/list_stream");
const stream_1 = require("./utils/stream");
const result_1 = require("./utils/result");
const result_writer_1 = require("./utils/result_writer");
async function deletePolicy(policy) {
    const params = {
        PolicyArn: policy.Arn
    };
    try {
        await iam_1.iam.deletePolicy(params).promise();
        result_1.OK('Deleted %1', policy.PolicyName);
    }
    catch (err) {
        if (err.code === 'DeleteConflict') {
            return result_1.NG('Failed to delete %1 attached on some roles', policy.PolicyName);
        }
        throw err;
    }
}
async function main(nameMatcher, opts = {}) {
    try {
        const policies = await promisedLife([
            new list_stream_1.ListPolicyStream({
                OnlyAttached: false,
                Scope: 'Local'
            }),
            stream_1.filterStream((policy) => {
                if (policy.PolicyName.match(nameMatcher)) {
                    console.info(policy.Arn);
                    return true;
                }
                return false;
            })
        ], { needResult: true });
        if (policies.length === 0) {
            console.info('Not found policies');
            return;
        }
        if (process.env.NODE_ENV !== 'test') {
            const answer = await prompt_1.default('Do you really delete above policies? yes|no> ');
            if (answer !== 'yes') {
                console.info('Abort.');
                return;
            }
        }
        return promisedLife([
            StreamUtils.readArray(policies),
            stream_1.promisedStream((policy) => deletePolicy(policy)),
            result_writer_1.createWriter(opts)
        ]);
    }
    catch (err) {
        console.error(err.stack);
        return false;
    }
}
exports.main = main;
