"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const policy_1 = require("../aws/policy");
const result_1 = require("../utils/result");
class PolicyRegisterer {
    constructor(opts = {}) {
        this._color = !(opts['plain'] || false);
        this._overwrite = opts['overwrite'] || false;
    }
    async register(policyFileInfo) {
        const { name } = policyFileInfo;
        try {
            await policy_1.createPolicy(policyFileInfo, 4);
            return result_1.OK('Created %1', name);
        }
        catch (err) {
            if (err.code === 'EntityAlreadyExists') {
                if (this._overwrite) {
                    return this._updatePolicyVersion(policyFileInfo);
                }
                else {
                    return result_1.Skip('%1 already exists.', name);
                }
            }
            else if (err.code === 'MalformedPolicyDocument') {
                return result_1.NG('%1 is invalid Policy JSON format.', name);
            }
            throw err;
        }
    }
    async _updatePolicyVersion({ name, document }) {
        const docJSON = policy_1.convertDocToJSON(document, 4);
        const arnPrefix = await policy_1.getPolicyArnPrefix();
        const { oldestId: deleteVerId, count, currentPolicy, } = await policy_1.getPolicyDefaultWithVersionInfoByArn(`${arnPrefix}/${name}`);
        if (docJSON === decodeURIComponent(currentPolicy.document)) {
            return result_1.Skip('%1 not changed', name);
        }
        else {
            if (count === 5) {
                await policy_1.deletePolicyVersion(currentPolicy.arn, deleteVerId);
                await policy_1.createPolicyDefaultVersion(currentPolicy.arn, docJSON, 4);
                return result_1.OK(`Updated %1 and deleted the oldest ${deleteVerId}`, name);
            }
            else {
                await policy_1.createPolicyDefaultVersion(currentPolicy.arn, docJSON, 4);
                return result_1.OK('Updated %1', name);
            }
        }
    }
}
exports.PolicyRegisterer = PolicyRegisterer;
