"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const jsonDiff = require('json-diff');
const policy_1 = require("../aws/policy");
const result_1 = require("../utils/result");
class PolicyValidator {
    constructor(opts = {}) {
        this._color = !(opts['plain'] || false);
        this._invalidCnt = 0;
    }
    async validate({ name, document }) {
        try {
            const arnPrefix = await policy_1.getPolicyArnPrefix();
            const { currentPolicy } = await policy_1.getPolicyDefaultWithVersionInfoByArn(`${arnPrefix}/${name}`);
            if (!currentPolicy) {
                this._invalidCnt++;
                return result_1.NG('%1 does not exist.', name);
            }
            const currentDoc = JSON.parse(decodeURIComponent(currentPolicy.document));
            const df = jsonDiff.diffString(currentDoc, document, { color: this._color });
            if (df) {
                this._invalidCnt++;
                return result_1.NG('%1 is invalid.', name, df);
            }
            else {
                return result_1.OK(name);
            }
        }
        catch (err) {
            if (err.code === 'NoSuchEntity') {
                return result_1.NG('%1 does not exist.', name);
            }
            throw err;
        }
    }
    isValid() {
        return this._invalidCnt === 0;
    }
}
exports.PolicyValidator = PolicyValidator;
